// Generated by Haxe 3.4.7
if (process.version < "v4.0.0") console.warn("Module " + (typeof(module) == "undefined" ? "" : module.filename) + " requires node.js version 4.0.0 or higher");
(function() {

// From: https://github.com/sokra/source-map-visualization

// PATCH: app.less
var CSS = `
* {
	font-family: Monaco,Menlo,Consolas,Courier New,monospace;
	font-size: 12px;
}
span.original-item {
	border-left: 1px solid black;
	margin: 1px;
	min-width: 3px;
}
span.generated-item {
	margin: 1px;
}
span.selected {
	background: black;
	color: white;
}
.style-0 {
	background: #FFFF66;
}
.style-1 {
	background: #FFFFFF;
}
.style-2 {
	background: #FFBBBB;
}
.style-3 {
	background: #AAFFFF;
}
.style-4 {
	background: #FFAAFF;
}

pre {
	overflow-x: auto;
}

pre code {
	white-space: pre-wrap;
	word-break: normal;
	word-wrap: normal;
}

table {
	width: 100%;
}

tr, td {
	vertical-align: top;
	margin: 0;
	width: 33%;
}`;

// PATCH: app.js, after HTML generation
var SCRIPT = `
	$("body").delegate(".original-item, .generated-item, .mapping-item", "mouseenter", function() {
		$(".selected").removeClass("selected");
		var mappedItems = $(this).data('mapped');
		if (!mappedItems){
			var source = $(this).data("source");
			var line = $(this).data("line");
			var column = $(this).data("column");
			mappedItems = $(".item-" + source + "-" + line + "-" + column);
			var twinItem = mappedItems.not('.mapping-item').not(this);
			$(this).data('mapped', mappedItems)
			$(this).data('twin', twinItem)
		}
		$(mappedItems).addClass("selected");
	}).delegate(".original-item, .generated-item, .mapping-item", "click", function() {
		var twinItem = $(this).data('twin');
		var elem = $(twinItem).get(0)
		if (elem && elem.scrollIntoViewIfNeeded)
			elem.scrollIntoViewIfNeeded();
	});
`;


// Original: generateHtml.js
var SourceMap = require("source-map");
var LINESTYLES = 5;
var MAX_LINES = 5000;

function formatSource(source) {
	return source.replace(/</g, "&lt;").split('/').pop();
}

global.generateHtml = function(map, generatedCode, sources) {
	var generatedSide = [];
	var originalSide = [];
	var mappingsSide = [];

	function addTo(side, line, html) {
		side[line] = (side[line] || "") + html;
	}

	function span(text, options) {
		var attrs = {};
		if(options) {
			if(options.generated) {
				attrs["class"] = "generated-item";
			} else if(options.mapping) {
				attrs["class"] = "mapping-item";
			} else {
				attrs["class"] = "original-item";
			}
			if(typeof options.source !== "undefined") {
				attrs["class"] += " item-" + options.source + "-" + options.line + "-" + options.column;
			}
			attrs["class"] += " style-" + (options.line%LINESTYLES);
			if (options.name) attrs["title"] = options.name;
			attrs["data-source"] = options.source;
			attrs["data-line"] = options.line;
			attrs["data-column"] = options.column;
		}
		return "<span " + Object.keys(attrs).filter(function(key) {
			return typeof attrs[key] !== "undefined";
		}).map(function(key) {
			return key + "=\"" + attrs[key] + "\"";
		}).join(" ") + ">" + (text + "").replace(/</g, "&lt;") + "</span>";
	}

	var mapSources = map.sources;

	var generatedLine = 1;
	var nodes = SourceMap.SourceNode.fromStringWithSourceMap(generatedCode, map).children;
	nodes.forEach(function(item, idx) {
		if(generatedLine > MAX_LINES) return;
		if(typeof item === "string") {
			item.split("\n").forEach(function(line) {
				addTo(generatedSide, generatedLine, line);
				generatedLine++;
			});
			generatedLine--;
		} else {
			var str = item.toString();
			var source = mapSources.indexOf(item.source);
			str.split("\n").forEach(function(line) {
				addTo(generatedSide, generatedLine, span(line, {
					generated: true,
					source: source,
					line: item.line,
					column: item.column,
					name: item.name
				}));
				generatedLine++
			});
			generatedLine--;
		}
	});


	var lastGenLine = 1;
	var lastOrgSource = "";
	var mappingsLine = 1;
	map.eachMapping(function(mapping) {
		if(mapping.generatedLine > MAX_LINES) return;
		while(lastGenLine < mapping.generatedLine) {
			mappingsLine++;
			lastGenLine++;
			addTo(mappingsSide, mappingsLine, lastGenLine + ": ");
		}
		if(typeof mapping.originalLine == "number") {
			if(lastOrgSource !== mapping.source && mapSources.length > 1) {
				addTo(mappingsSide, mappingsLine, "<b>[" + formatSource(mapping.source) + "]</b> ");
				lastOrgSource = mapping.source;
			}
			var source = mapSources.indexOf(mapping.source);
			addTo(mappingsSide, mappingsLine, span(mapping.generatedColumn + "->" + mapping.originalLine + ":" + mapping.originalColumn, {
				mapping: true,
				source: source,
				line: mapping.originalLine,
				column: mapping.originalColumn
			}));
		} else {
			addTo(mappingsSide, mappingsLine, span(mapping.generatedColumn, {
				mapping: true
			}));
		}
		addTo(mappingsSide, mappingsLine, "  ");
	});


	var originalLine = 1;
	var line = 1, column = 0, currentOutputLine = 1, targetOutputLine = -1, limited = false;
	var lastMapping = null;
	var currentSource = null;
	var exampleLines;
	var mappingsBySource = {};
	map.eachMapping(function(mapping) {
		if(typeof mapping.originalLine !== "number") return;
		if(mapping.generatedLine > MAX_LINES) return limited = true;
		if(!mappingsBySource[mapping.source]) mappingsBySource[mapping.source] = [];
		mappingsBySource[mapping.source].push(mapping);
	}, undefined, SourceMap.SourceMapConsumer.ORIGINAL_ORDER);
	Object.keys(mappingsBySource).map(function(source) {
		return [source, mappingsBySource[source][0].generatedLine];
	}).sort(function(a, b) {
		if(a[0] === "?") return 1;
		if(b[0] === "?") return -1;
		return a[1] - b[1];
	}).forEach(function(arr) {
		var source = arr[0];
		var mappings = mappingsBySource[source];

		if(currentSource) endFile();
		lastMapping = null;
		line = 1;
		column = 0;
		targetOutputLine = -1;
		if(mapSources.length > 1) {
			currentOutputLine++;
		}
		var startLine = mappings.map(function(mapping) {
			return mapping.generatedLine - mapping.originalLine + 1;
		}).sort(function(a, b) { return a - b });
		startLine = startLine[0];
		while(currentOutputLine < startLine) {
			originalLine++;
			currentOutputLine++;
		}
		if(mapSources.length > 1) {
			addTo(originalSide, originalLine, "<h4>[" + formatSource(source) + "]</h4>");
			originalLine++;
		}
		var exampleSource = sources[mapSources.indexOf(source)];
		if(!exampleSource) throw new Error("Source '" + source + "' missing");
		exampleLines = exampleSource.split("\n");
		currentSource = source;
		mappings.forEach(function(mapping, idx) {
			if(lastMapping) {
				var source = mapSources.indexOf(lastMapping.source);
				if(line < mapping.originalLine) {
					addTo(originalSide, originalLine, span(exampleLines.shift(), {
						original: true,
						source: source,
						line: lastMapping.originalLine,
						column: lastMapping.originalColumn
					}));
					originalLine++;
					line++; column = 0;
					currentOutputLine++;
					while(line < mapping.originalLine) {
						addTo(originalSide, originalLine, exampleLines.shift());
						originalLine++;
						line++; column = 0;
						currentOutputLine++;
					}
					startLine = [];
					for(var i = idx; i < mappings.length && mappings[i].originalLine <= mapping.originalLine + 1; i++) {
						startLine.push(mappings[i].generatedLine - mappings[i].originalLine + mapping.originalLine);
					}
					startLine.sort(function(a, b) { return a - b });
					startLine = startLine[0];
					while(typeof startLine !== "undefined" && currentOutputLine < startLine) {
						addTo(originalSide, originalLine, "~");
						originalLine++;
						currentOutputLine++;
					}
					if(column < mapping.originalColumn) {
						addTo(originalSide, originalLine, shiftColumns(mapping.originalColumn - column));
					}
				}
				if(mapping.originalColumn > column) {
					addTo(originalSide, originalLine, span(shiftColumns(mapping.originalColumn - column), {
						original: true,
						source: source,
						line: lastMapping.originalLine,
						column: lastMapping.originalColumn
					}));
				}
			} else {
				while(line < mapping.originalLine) {
					addTo(originalSide, originalLine, exampleLines.shift());
					originalLine++;
					line++; column = 0;
				}
				if(column < mapping.originalColumn) {
					addTo(originalSide, originalLine, shiftColumns(mapping.originalColumn - column));
				}
			}
			lastMapping = mapping;
		});
	});
	function endFile() {
		if(lastMapping) {
			var source = mapSources.indexOf(lastMapping.source);
			addTo(originalSide, originalLine, span(exampleLines.shift(), {
				original: true,
				source: source,
				line: lastMapping.originalLine,
				column: lastMapping.originalColumn
			}));
		}
		if(!limited) {
			exampleLines.forEach(function(line) {
				originalLine++;
				currentOutputLine++;
				addTo(originalSide, originalLine, line);
			});
		}
	}
	endFile();

	function shiftColumns(count) {
		var nextLine = exampleLines[0];
		exampleLines[0] = nextLine.substr(count);
		column += count;
		return nextLine.substr(0, count);
	}

	var length = Math.max(originalSide.length, generatedSide.length, mappingsSide.length);

	var tableRows = [];

	for(var i = 0; i < length; i++) {
		tableRows[i] = [
			originalSide[i] || "",
			generatedSide[i] || "",
			mappingsSide[i] || ""
		].map(function(cell) {
			return "<td>" + cell + "</td>";
		}).join("");
	}

	return "<!DOCTYPE html>\n<html>\n<style>" + CSS + "</style>\n<table><tbody>\n" + tableRows.map(function(row) {
		return "<tr>" + row + "</tr>\n";
	}).join("") + "</tbody></table>\n"
	+ '<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js"/></script><script>' + SCRIPT + "</script></html>";


}

})();

(function ($hx_exports) { "use strict";
function $extend(from, fields) {
	function Inherit() {} Inherit.prototype = from; var proto = new Inherit();
	for (var name in fields) proto[name] = fields[name];
	if( fields.toString !== Object.prototype.toString ) proto.toString = fields.toString;
	return proto;
}
var SourceMapConsumer = require("source-map").SourceMapConsumer;
var Bundler = function(parser,sourceMap,extractor,reporter) {
	this.parser = parser;
	this.sourceMap = sourceMap;
	this.extractor = extractor;
	this.reporter = reporter;
	this.minifyId = new MinifyId();
};
Bundler.__name__ = true;
Bundler.prototype = {
	generate: function(src,output,commonjs,debugSourceMap) {
		this.commonjs = commonjs;
		this.debugSourceMap = this.sourceMap != null && debugSourceMap;
		this.bundles = [this.extractor.main].concat(this.extractor.bundles);
		this.revMap = { };
		var len = this.bundles.length;
		var _g1 = 0;
		var _g = len;
		while(_g1 < _g) {
			var i = _g1++;
			this.createRevMap(i,this.bundles[i]);
		}
		this.buildIndex(src);
		var results = [];
		var _g11 = 0;
		var _g2 = len;
		while(_g11 < _g2) {
			var i1 = _g11++;
			var bundle = this.bundles[i1];
			var isMain = bundle.isMain;
			var bundleOutput = isMain ? output : js_node_Path.join(js_node_Path.dirname(output),bundle.name + ".js");
			haxe_Log.trace("Emit " + bundleOutput,{ fileName : "Bundler.hx", lineNumber : 95, className : "Bundler", methodName : "generate"});
			var buffer = this.emitBundle(src,bundle,isMain);
			results[i1] = { name : bundle.name, map : this.writeMap(bundleOutput,buffer), source : this.write(bundleOutput,buffer.src), debugMap : buffer.debugMap};
			isMain = false;
		}
		return results;
	}
	,buildIndex: function(src) {
		var ids = this.idMap = { };
		if(!this.commonjs) {
			ids["require"] = true;
		}
		var rev = this.revMap;
		var body = this.parser.rootBody;
		var bodyLength = body.length;
		var bundlesLength = this.bundles.length;
		var _g1 = 1;
		var _g = bodyLength;
		while(_g1 < _g) {
			var i = _g1++;
			var node = body[i];
			if(node.__tag__ == null) {
				node.__main__ = true;
				var _g3 = 1;
				var _g2 = bundlesLength;
				while(_g3 < _g2) {
					var j = _g3++;
					this.bundles[j].indexes.push(i);
				}
			} else if(node.__tag__ != "__reserved__") {
				ids[node.__tag__] = true;
				var list = rev[node.__tag__];
				if(list == null) {
					list = [0];
				}
				var _g31 = 0;
				var _g21 = list.length;
				while(_g31 < _g21) {
					var j1 = _g31++;
					var index = list[j1];
					if(index == 0) {
						node.__main__ = true;
					} else {
						this.bundles[index].indexes.push(i);
					}
				}
			} else {
				node.__main__ = true;
			}
		}
	}
	,createRevMap: function(index,bundle) {
		this.minifyId.set(bundle.name);
		var rev = this.revMap;
		var nodes = bundle.nodes;
		var len = nodes.length;
		var _g1 = 0;
		var _g = len;
		while(_g1 < _g) {
			var i = _g1++;
			var list = rev[nodes[i]];
			if(list != null) {
				list.push(index);
			} else {
				rev[nodes[i]] = [index];
			}
		}
	}
	,writeMap: function(output,buffer) {
		if(this.sourceMap == null || buffer.map == null) {
			return null;
		}
		return { path : "" + output + ".map", content : this.sourceMap.emitFile(output,buffer.map)};
	}
	,write: function(output,buffer) {
		if(buffer == null) {
			return null;
		}
		return { path : output, content : buffer};
	}
	,emitBundle: function(src,bundle,isMain) {
		var output = this.emitJS(src,bundle,isMain);
		var map = this.sourceMap != null ? this.sourceMap.emitMappings(output.mapNodes,output.mapOffset) : null;
		var debugMap = this.debugSourceMap && map != null ? this.emitDebugMap(output.buffer,bundle,map) : null;
		return { src : output.buffer, map : map, debugMap : debugMap};
	}
	,emitDebugMap: function(src,bundle,rawMap) {
		if(rawMap.sources.length == 0) {
			return null;
		}
		rawMap.sources = rawMap.sources.map(function(url) {
			if(url == "") {
				return null;
			} else {
				return url;
			}
		});
		var consumer = new SourceMapConsumer(rawMap);
		var _g = [];
		var _g1 = 0;
		var _g2 = rawMap.sources;
		while(_g1 < _g2.length) {
			var source = _g2[_g1];
			++_g1;
			var tmp;
			if(source == null || source == "") {
				tmp = "";
			} else {
				var fileName = source.split("file://").pop();
				tmp = js_node_Fs.readFileSync(fileName).toString();
			}
			_g.push(tmp);
		}
		var sourcesContent = _g;
		try {
			return Bundler.generateHtml(consumer,src,sourcesContent);
		} catch( err ) {
			if (err instanceof js__$Boot_HaxeError) err = err.val;
			haxe_Log.trace("[WARNING] error while generating debug map for " + bundle.name + ": " + Std.string(err),{ fileName : "Bundler.hx", lineNumber : 231, className : "Bundler", methodName : "emitDebugMap"});
			return null;
		}
	}
	,emitJS: function(src,bundle,isMain) {
		var _gthis = this;
		this.reporter.start(bundle);
		var mapOffset = 0;
		var imports = Reflect.fields(bundle.imports);
		var shared = Reflect.fields(bundle.shared);
		var exports = Reflect.fields(bundle.exports);
		var buffer = "";
		var body = this.parser.rootBody;
		var hasSourceMap = this.sourceMap != null;
		if(isMain) {
			buffer += this.getBeforeBodySrc(src);
			if(hasSourceMap) {
				mapOffset += this.getBeforeBodyOffset();
			}
		} else {
			++mapOffset;
		}
		var inc = bundle.nodes;
		var incAll = isMain && bundle.nodes.length == 0;
		var mapNodes = [];
		var frag = isMain || bundle.isLib ? Bundler.FRAGMENTS.MAIN : Bundler.FRAGMENTS.CHILD;
		if(this.commonjs) {
			buffer += "/* eslint-disable */ \"use strict\"\n";
			++mapOffset;
			buffer += frag.EXPORTS;
			++mapOffset;
			buffer += frag.SHARED;
			++mapOffset;
		} else {
			buffer += "(function ($hx_exports, $global) { \"use-strict\";\n";
			++mapOffset;
			buffer += frag.SHARED;
			++mapOffset;
			if(isMain) {
				buffer += "var require = (function(r){ return function require(m) { return r[m]; } })($s.__registry__ || {});\n";
				++mapOffset;
			}
		}
		if(imports.length > 0 || shared.length > 0) {
			var _g = [];
			var _g1 = 0;
			while(_g1 < imports.length) {
				var node = imports[_g1];
				++_g1;
				_g.push("" + node + " = $" + "s." + this.minifyId.get(node));
			}
			var tmp = shared.concat(_g);
			buffer += "var " + tmp.join(", ") + ";\n";
			++mapOffset;
		}
		if(isMain) {
			var len = body.length - 1;
			var _g11 = 1;
			var _g2 = len;
			while(_g11 < _g2) {
				var i = _g11++;
				var node1 = body[i];
				if(!incAll && !node1.__main__) {
					continue;
				}
				if(hasSourceMap) {
					mapNodes.push(node1);
				}
				var chunk = HxOverrides.substr(src,node1.start,node1.end - node1.start);
				this.reporter.add(node1.__tag__,chunk.length);
				buffer += chunk;
				buffer += "\n";
			}
		} else {
			var indexes = bundle.indexes;
			var len1 = indexes.length;
			var _g12 = 0;
			var _g3 = len1;
			while(_g12 < _g3) {
				var i1 = _g12++;
				var node2 = body[indexes[i1]];
				if(hasSourceMap) {
					mapNodes.push(node2);
				}
				var chunk1 = HxOverrides.substr(src,node2.start,node2.end - node2.start);
				this.reporter.add(node2.__tag__,chunk1.length);
				buffer += chunk1;
				buffer += "\n";
			}
		}
		if(this.parser.isHot != null) {
			buffer += this.emitHot(inc);
		}
		if(exports.length > 0) {
			var _g4 = 0;
			while(_g4 < exports.length) {
				var node3 = exports[_g4];
				++_g4;
				if(node3.charAt(0) == "$" || Object.prototype.hasOwnProperty.call(this.idMap,node3)) {
					buffer += "$" + "s." + this.minifyId.get(node3) + " = " + node3 + "; ";
				}
			}
			buffer += "\n";
		}
		if(isMain) {
			var run = body[body.length - 1];
			buffer += HxOverrides.substr(src,run.start,run.end - run.start);
			buffer += "\n";
			var _g5 = 0;
			var _g13 = this.extractor.bundles;
			while(_g5 < _g13.length) {
				var bundle1 = _g13[_g5];
				++_g5;
				if(!bundle1.isLib) {
					continue;
				}
				var match = "\"" + bundle1.name + "__BRIDGE__\"";
				var bridge = Reflect.fields(bundle1.exports).filter(function(node4) {
					return shared.indexOf(node4) >= 0;
				}).map(function(node5) {
					return "" + node5 + " = $" + "s." + _gthis.minifyId.get(node5);
				}).join(", ");
				if(bridge == "") {
					bridge = "0";
				}
				buffer = buffer.split(match).join("(" + bridge + ")");
			}
		}
		if(!this.commonjs) {
			buffer += "})(" + "typeof exports != \"undefined\" ? exports : typeof window != \"undefined\" ? window : typeof self != \"undefined\" ? self : this" + ", " + "typeof window != \"undefined\" ? window : typeof global != \"undefined\" ? global : typeof self != \"undefined\" ? self : this" + ");\n";
		}
		return { buffer : buffer, mapNodes : mapNodes, mapOffset : mapOffset};
	}
	,getBeforeBodyOffset: function() {
		return this.parser.rootExpr.loc.start.line;
	}
	,getBeforeBodySrc: function(src) {
		var chunk = HxOverrides.substr(src,0,this.parser.rootExpr.start);
		this.reporter.includedBefore(chunk.length);
		return chunk;
	}
	,emitHot: function(inc) {
		var names = [];
		var _g = 0;
		var _g1 = Reflect.fields(this.parser.isHot);
		while(_g < _g1.length) {
			var name = _g1[_g];
			++_g;
			if(this.parser.isHot[name] && inc.indexOf(name) >= 0) {
				names.push(name);
			}
		}
		if(names.length == 0) {
			return "";
		}
		return "if ($" + "global.__REACT_HOT_LOADER__)\n" + ("  [" + names.join(",") + "].map(function(c) {\n") + "    __REACT_HOT_LOADER__.register(c,c.displayName,c.__fileName__);\n" + "  });\n";
	}
};
var Extractor = function(parser) {
	this.parser = parser;
};
Extractor.__name__ = true;
Extractor.prototype = {
	process: function(mainModule,modulesList,debugMode) {
		var _gthis = this;
		var t0 = new Date().getTime();
		haxe_Log.trace("Bundling...",{ fileName : "Extractor.hx", lineNumber : 48, className : "Extractor", methodName : "process"});
		this.moduleMap = { };
		this.parenting = new graphlib_Graph();
		this.moduleTest = { };
		if(this.parser.typesCount == 0) {
			haxe_Log.trace("Warning: unable to process (no type metadata)",{ fileName : "Extractor.hx", lineNumber : 54, className : "Extractor", methodName : "process"});
			this.main = this.createBundle(mainModule);
			this.bundles = [this.main];
			return;
		}
		this.g = this.parser.graph;
		this.hmrMode = debugMode;
		this.mainModule = mainModule;
		this.uniqueModules(modulesList);
		var _g = 0;
		while(_g < modulesList.length) {
			var $module = modulesList[_g];
			++_g;
			this.moduleTest[$module] = true;
		}
		this.linkOrphans();
		if(debugMode) {
			this.linkEnums(mainModule,Reflect.fields(this.parser.isEnum));
		}
		var libTest = this.expandLibs();
		var parents = { };
		this.recurseVisit([mainModule],libTest,parents);
		this.recurseVisit(this.modules,libTest,parents);
		this.walkLibs(libTest,parents);
		this.populateBundles(mainModule,parents);
		this.main = this.moduleMap[mainModule];
		this.bundles = this.modules.map(function(module1) {
			var name = module1.indexOf("=") > 0 ? module1.split("=")[0] : module1;
			return _gthis.moduleMap[name];
		}).filter(function(bundle) {
			return bundle != null;
		});
		var t1 = new Date().getTime();
		haxe_Log.trace("Graph processed in: " + (t1 - t0) + "ms",{ fileName : "Extractor.hx", lineNumber : 91, className : "Extractor", methodName : "process"});
	}
	,populateBundles: function(mainModule,parents) {
		var bundle = this.moduleMap[mainModule];
		this.recursePopulate(bundle,mainModule,parents,{ });
	}
	,recursePopulate: function(bundle,root,parents,visited) {
		bundle.nodes.push(root);
		var $module = bundle.name;
		var succ = this.g.successors(root);
		var parent;
		var _g = 0;
		while(_g < succ.length) {
			var node = succ[_g];
			++_g;
			var parentModule = parents[node];
			if(parentModule == $module) {
				parent = bundle;
			} else {
				parent = this.moduleMap[parentModule];
				if(bundle.isMain) {
					bundle.shared[node] = true;
				} else if(node == parentModule) {
					if(this.parenting.hasEdge($module,parentModule)) {
						bundle.shared[node] = true;
					} else {
						bundle.imports[node] = true;
					}
				} else {
					bundle.imports[node] = true;
				}
				parent.exports[node] = true;
			}
			if(Object.prototype.hasOwnProperty.call(visited,node)) {
				continue;
			}
			visited[node] = true;
			this.recursePopulate(parent,node,parents,visited);
		}
	}
	,walkLibs: function(libTest,parents) {
		var children = [];
		var _g = 0;
		while(_g < libTest.length) {
			var lib = [libTest[_g]];
			++_g;
			var _g1 = 0;
			var _g2 = Reflect.fields(lib[0].roots);
			while(_g1 < _g2.length) {
				var node = _g2[_g1];
				++_g1;
				var test = libTest.filter((function(lib1) {
					return function(it) {
						return it != lib1[0];
					};
				})(lib));
				if(Object.prototype.hasOwnProperty.call(parents,node)) {
					continue;
				}
				parents[node] = lib[0].bundle.name;
				this.walkGraph(lib[0].bundle,node,test,parents,children);
			}
		}
	}
	,recurseVisit: function(modules,libTest,parents) {
		var children = [];
		var _g = 0;
		while(_g < modules.length) {
			var $module = modules[_g];
			++_g;
			if($module.indexOf("=") > 0 || Object.prototype.hasOwnProperty.call(this.moduleMap,$module) || !this.g.hasNode($module)) {
				continue;
			}
			var mod = this.createBundle($module);
			parents[$module] = $module;
			this.walkGraph(mod,$module,libTest,parents,children);
		}
		if(children.length > 0) {
			this.recurseVisit(children,libTest,parents);
		}
	}
	,walkGraph: function(bundle,target,libTest,parents,children) {
		var $module = bundle.name;
		var succ = this.g.successors(target);
		var _g = 0;
		while(_g < succ.length) {
			var node = succ[_g];
			++_g;
			if(Object.prototype.hasOwnProperty.call(this.moduleTest,node)) {
				var childModule = node;
				if(!this.parenting.hasEdge(childModule,$module)) {
					this.parenting.setEdge($module,childModule);
					children.push(childModule);
				}
				continue;
			}
			var lib = this.libMap[node];
			var tmp;
			if(lib != null && libTest.indexOf(lib) >= 0) {
				lib.roots[node] = true;
				tmp = true;
			} else {
				tmp = false;
			}
			if(tmp) {
				continue;
			}
			if(Object.prototype.hasOwnProperty.call(parents,node)) {
				var ownerModule = parents[node];
				if(ownerModule == $module) {
					continue;
				}
				var owner = this.moduleMap[ownerModule];
				if(!owner.isMain) {
					var parentModule = this.commonParent(bundle,owner);
					var parent = this.moduleMap[parentModule];
					if(parent != owner) {
						this.shareGraph(parent,owner,node,parents);
					}
				}
				continue;
			}
			parents[node] = $module;
			this.walkGraph(bundle,node,libTest,parents,children);
		}
	}
	,shareGraph: function(toBundle,fromBundle,root,parents) {
		var toModule = toBundle.name;
		var fromModule = fromBundle.name;
		parents[root] = toModule;
		var succ = this.g.successors(root);
		var _g = 0;
		while(_g < succ.length) {
			var node = succ[_g];
			++_g;
			var current = parents[node];
			if(current == fromModule) {
				this.shareGraph(toBundle,fromBundle,node,parents);
			}
		}
	}
	,commonParent: function(b1,b2) {
		var p1 = this.parentsOf(b1.name,{ });
		var p2 = this.parentsOf(b2.name,{ });
		var i1 = p1.length - 1;
		var i2 = p2.length - 1;
		var parent = this.mainModule;
		while(p1[i1] == p2[i2] && i1 >= 0) {
			parent = p1[i1];
			--i1;
			--i2;
		}
		return parent;
	}
	,parentsOf: function(module,visited) {
		var pred = this.parenting.predecessors(module);
		var best = null;
		var _g = 0;
		while(_g < pred.length) {
			var p = pred[_g];
			++_g;
			if(Object.prototype.hasOwnProperty.call(visited,p)) {
				continue;
			}
			visited[p] = true;
			var parents = this.parentsOf(p,visited);
			if(best == null) {
				best = parents;
			} else if(parents.length < best.length) {
				best = parents;
			}
		}
		if(best == null) {
			best = [this.mainModule];
		} else {
			best.unshift(module);
		}
		return best;
	}
	,isInLib: function(node,libTest) {
		var lib = this.libMap[node];
		if(lib != null && libTest.indexOf(lib) >= 0) {
			lib.roots[node] = true;
			return true;
		}
		return false;
	}
	,uniqueModules: function(modulesList) {
		this.modules = [];
		var modulesMap = { };
		var _g = 0;
		while(_g < modulesList.length) {
			var $module = modulesList[_g];
			++_g;
			if($module.indexOf("=") > 0) {
				var parts = $module.split("=");
				var name = parts[0];
				if(!Object.prototype.hasOwnProperty.call(modulesMap,name)) {
					modulesMap[name] = [];
				}
				var _g1 = 0;
				var _g2 = parts[1].split(",");
				while(_g1 < _g2.length) {
					var m = _g2[_g1];
					++_g1;
					if(modulesMap[name].indexOf(m) < 0) {
						modulesMap[name].push(m);
					}
				}
			} else if(this.modules.indexOf($module) < 0) {
				this.modules.push($module);
			}
		}
		var tmp = this.modules;
		var _g3 = [];
		var _g11 = 0;
		var _g21 = Reflect.fields(modulesMap);
		while(_g11 < _g21.length) {
			var name1 = _g21[_g11];
			++_g11;
			_g3.push("" + name1 + "=" + modulesMap[name1].join(","));
		}
		this.modules = tmp.concat(_g3);
	}
	,linkEnums: function(root,list) {
		var _g = 0;
		while(_g < list.length) {
			var node = list[_g];
			++_g;
			this.g.setEdge(root,node);
		}
	}
	,linkOrphans: function() {
		var sources = this.g.sources();
		var _g = 0;
		while(_g < sources.length) {
			var source = sources[_g];
			++_g;
			if(source != this.mainModule) {
				this.g.setEdge(this.mainModule,source);
			}
		}
		var _g1 = 0;
		var _g11 = ["$estr","$hxClasses","$hxEnums","Std"];
		while(_g1 < _g11.length) {
			var enforce = _g11[_g1];
			++_g1;
			if(!this.g.hasNode(enforce)) {
				continue;
			}
			if(!this.g.hasEdge(this.mainModule,enforce)) {
				this.g.setEdge(this.mainModule,enforce);
			}
		}
	}
	,createBundle: function(name,isLib) {
		if(isLib == null) {
			isLib = false;
		}
		var bundle = { isMain : name == this.mainModule, isLib : isLib, name : name, nodes : [], indexes : [], exports : { }, shared : { }, imports : { }};
		if(!this.parenting.hasNode(name)) {
			this.parenting.setNode(name);
		}
		this.moduleMap[name] = bundle;
		return bundle;
	}
	,expandLibs: function() {
		this.libMap = { };
		var libTest = [];
		var allNodes = this.parser.graph.nodes();
		var _g1 = 0;
		var _g = this.modules.length;
		while(_g1 < _g) {
			var i = _g1++;
			var $module = this.modules[i];
			if($module.indexOf("=") > 0) {
				var lib = this.resolveLib($module);
				this.mapLibTypes(allNodes,lib);
				libTest.push(lib);
			}
		}
		return libTest;
	}
	,mapLibTypes: function(allNodes,lib) {
		var test = lib.test;
		var n = test.length;
		var _g1 = 0;
		var _g = allNodes.length;
		while(_g1 < _g) {
			var i = _g1++;
			var node = allNodes[i];
			var _g3 = 0;
			var _g2 = n;
			while(_g3 < _g2) {
				var j = _g3++;
				if(node.startsWith(test[j])) {
					this.libMap[node] = lib;
					break;
				}
			}
		}
	}
	,resolveLib: function(name) {
		var parts = name.split("=");
		var newName = parts[0];
		var tmp = parts[1].split(",");
		var tmp1 = this.createBundle(newName,true);
		return { test : tmp, roots : { }, bundle : tmp1};
	}
	,addOnce: function(source,target) {
		var temp = target.slice();
		var _g = 0;
		while(_g < source.length) {
			var node = source[_g];
			++_g;
			if(target.indexOf(node) < 0) {
				temp.push(node);
			}
		}
		return temp;
	}
};
var HxOverrides = function() { };
HxOverrides.__name__ = true;
HxOverrides.cca = function(s,index) {
	var x = s.charCodeAt(index);
	if(x != x) {
		return undefined;
	}
	return x;
};
HxOverrides.substr = function(s,pos,len) {
	if(len == null) {
		len = s.length;
	} else if(len < 0) {
		if(pos == 0) {
			len = s.length + len;
		} else {
			return "";
		}
	}
	return s.substr(pos,len);
};
var HxSplit = function() { };
HxSplit.__name__ = true;
HxSplit.run = $hx_exports["run"] = function(input,output,modules,debugMode,commonjs,debugSourceMap,dump,astHooks) {
	haxe_Log.trace = function(v,infos) {
		console.log(v);
	};
	var src = js_node_Fs.readFileSync(input).toString();
	var parser = new Parser(src,debugMode,commonjs);
	var sourceMap = debugMode ? new SourceMap(input,src) : null;
	modules = HxSplit.applyAstHooks(parser.mainModule,modules,astHooks,parser.graph);
	if(debugSourceMap) {
		HxSplit.dumpGraph(output,parser.graph);
	}
	var extractor = new Extractor(parser);
	extractor.process(parser.mainModule,modules,debugMode);
	var reporter = new Reporter(dump);
	var bundler = new Bundler(parser,sourceMap,extractor,reporter);
	var result = bundler.generate(src,output,commonjs,debugSourceMap);
	if(debugSourceMap) {
		HxSplit.dumpModules(output,extractor);
	}
	if(dump) {
		reporter.save(output);
	}
	return result;
};
HxSplit.applyAstHooks = function(mainModule,modules,astHooks,graph) {
	if(astHooks == null || astHooks.length == 0) {
		return modules;
	}
	var _g = 0;
	while(_g < astHooks.length) {
		var hook = astHooks[_g];
		++_g;
		if(hook == null) {
			continue;
		}
		var addModules = hook(graph,mainModule);
		if(addModules != null) {
			modules = modules.concat(addModules);
		}
	}
	return modules;
};
HxSplit.dumpModules = function(output,extractor) {
	haxe_Log.trace("Dump bundles: " + output + ".json",{ fileName : "HxSplit.hx", lineNumber : 53, className : "HxSplit", methodName : "dumpModules"});
	var bundles = [extractor.main].concat(extractor.bundles);
	var _g = 0;
	while(_g < bundles.length) {
		var bundle = bundles[_g];
		++_g;
		Reflect.deleteField(bundle,"indexes");
		bundle.nodes.sort(function(s1,s2) {
			if(s1 == s2) {
				return 0;
			} else if(s1 < s2) {
				return -1;
			} else {
				return 1;
			}
		});
	}
	var out = JSON.stringify(bundles,null,"  ");
	js_node_Fs.writeFileSync(output + ".json",out);
};
HxSplit.dumpGraph = function(output,g) {
	haxe_Log.trace("Dump graph: " + output + ".graph",{ fileName : "HxSplit.hx", lineNumber : 66, className : "HxSplit", methodName : "dumpGraph"});
	var out = "";
	var _g = 0;
	var _g1 = g.nodes();
	while(_g < _g1.length) {
		var node = _g1[_g];
		++_g;
		if(node.charAt(0) != "$") {
			var toNode = g.inEdges(node).map(function(n) {
				return n.v.split("_").join(".");
			}).filter(function(l) {
				return l.charAt(0) != "$";
			});
			if(toNode.length == 0) {
				continue;
			}
			out += "+ " + node + " < " + toNode.join(", ") + "\n";
			var fromNode = g.outEdges(node).map(function(n1) {
				return n1.w.split("_").join(".");
			}).filter(function(l1) {
				return l1.charAt(0) != "$";
			});
			var _g2 = 0;
			while(_g2 < fromNode.length) {
				var dest = fromNode[_g2];
				++_g2;
				out += "  - " + dest + "\n";
			}
		}
	}
	js_node_Fs.writeFileSync(output + ".graph",out);
};
Math.__name__ = true;
var MinifyId = function() {
	this.index = 0;
	this.map = { };
};
MinifyId.__name__ = true;
MinifyId.prototype = {
	set: function(id) {
		this.map[id] = id;
	}
	,get: function(id) {
		if(id.length <= 2) {
			return id;
		}
		var min = this.map[id];
		if(min == null) {
			var B16 = MinifyId.BASE_16;
			var i = this.index++;
			min = "";
			while(i > 15) {
				var add = i & 15;
				i = (i >> 4) - 1;
				min = B16[add] + min;
			}
			min = B16[i] + min;
			this.map[id] = min;
		}
		return min;
	}
};
var Parser = function(src,withLocation,commonjs) {
	this.objectMethods = { "defineProperty" : true, "defineProperties" : true, "freeze" : true};
	this.reservedTypes = { "String" : true, "Math" : true, "Array" : true, "Date" : true, "Number" : true, "Boolean" : true, __map_reserved : true};
	this.mainModule = "Main";
	var t0 = new Date().getTime();
	this.processInput(src,withLocation);
	var t1 = new Date().getTime();
	haxe_Log.trace("Parsed in: " + (t1 - t0) + "ms",{ fileName : "Parser.hx", lineNumber : 31, className : "Parser", methodName : "new"});
	this.buildGraph(commonjs);
	var t2 = new Date().getTime();
	haxe_Log.trace("AST processed in: " + (t2 - t1) + "ms",{ fileName : "Parser.hx", lineNumber : 35, className : "Parser", methodName : "new"});
};
Parser.__name__ = true;
Parser.prototype = {
	processInput: function(src,withLocation) {
		var options = { ecmaVersion : 5, allowReserved : true};
		if(withLocation) {
			options.locations = true;
		}
		var program = acorn_Acorn.parse(src,options);
		this.walkProgram(program);
	}
	,buildGraph: function(commonjs) {
		var g = new graphlib_Graph({ directed : true, compound : true});
		var cpt = 0;
		var refs = 0;
		var _g = 0;
		var _g1 = Reflect.fields(this.types);
		while(_g < _g1.length) {
			var t = _g1[_g];
			++_g;
			++cpt;
			g.setNode(t,t);
		}
		if(!commonjs) {
			this.types["require"] = [];
			g.setNode("require","require");
			g.setEdge(this.mainModule,"require");
		}
		var _g2 = 0;
		var _g11 = Reflect.fields(this.types);
		while(_g2 < _g11.length) {
			var t1 = _g11[_g2];
			++_g2;
			refs += this.walk(g,t1,this.types[t1]);
		}
		haxe_Log.trace("Stats: " + cpt + " types, " + refs + " references",{ fileName : "Parser.hx", lineNumber : 66, className : "Parser", methodName : "buildGraph"});
		this.typesCount = cpt;
		this.graph = g;
	}
	,walk: function(g,id,nodes) {
		var _gthis = this;
		var refs = 0;
		var visitors = { Identifier : function(node) {
			var name = node.name;
			if(name != id && Object.prototype.hasOwnProperty.call(_gthis.types,name)) {
				g.setEdge(id,name);
				refs += 1;
			}
		}, AssignmentExpression : function(node1,state,cont) {
			cont(node1.right,state);
			cont(node1.left,state);
		}};
		var _g = 0;
		while(_g < nodes.length) {
			var decl = nodes[_g];
			++_g;
			acorn_Walk.recursive(decl,{ },visitors);
		}
		return refs;
	}
	,walkProgram: function(program) {
		this.types = { };
		this.isEnum = { };
		this.isRequire = { };
		var body = this.getBodyNodes(program);
		this.rootExpr = body.pop();
		var _g = this.rootExpr.type;
		if(_g == "ExpressionStatement") {
			this.walkRootExpression(this.rootExpr.expression);
		} else {
			throw new js__$Boot_HaxeError("Expecting last node to be an ExpressionStatement");
		}
	}
	,walkRootExpression: function(expr) {
		var _g = expr.type;
		if(_g == "CallExpression") {
			this.walkRootFunction(expr.callee);
		} else {
			throw new js__$Boot_HaxeError("Expecting last node statement to be a function call");
		}
	}
	,walkRootFunction: function(callee) {
		var block = this.getBodyNodes(callee)[0];
		var _g = block.type;
		if(_g == "BlockStatement") {
			var body = this.getBodyNodes(block);
			this.walkDeclarations(body);
		} else {
			throw new js__$Boot_HaxeError("Expecting block of statements inside root function");
		}
	}
	,walkDeclarations: function(body) {
		this.rootBody = body;
		var _g = 0;
		while(_g < body.length) {
			var node = body[_g];
			++_g;
			var _g1 = node.type;
			switch(_g1) {
			case "EmptyStatement":
				break;
			case "ExpressionStatement":
				this.inspectExpression(node.expression,node);
				break;
			case "FunctionDeclaration":
				this.inspectFunction(node.id,node);
				break;
			case "IfStatement":
				if(node.consequent.type == "ExpressionStatement") {
					this.inspectExpression(node.consequent.expression,node);
				} else {
					this.inspectIfStatement(node.test,node);
				}
				break;
			case "VariableDeclaration":
				this.inspectDeclarations(node.declarations,node);
				break;
			default:
				haxe_Log.trace("WARNING: Unexpected " + node.type + ", at character " + node.start,{ fileName : "Parser.hx", lineNumber : 158, className : "Parser", methodName : "walkDeclarations"});
			}
		}
	}
	,inspectIfStatement: function(test,def) {
		if(test.type == "BinaryExpression") {
			var path = this.getIdentifier(test.left);
			if(path.length > 1 && path[1] == "prototype") {
				this.tag(path[0],def);
			}
		}
	}
	,inspectFunction: function(id,def) {
		var path = this.getIdentifier(id);
		if(path.length > 0) {
			var name = path[0];
			if(name == "$extend" || name == "$bind" || name == "$iterator") {
				this.tag(name,def);
			}
		}
	}
	,inspectExpression: function(expression,def) {
		var _g = expression.type;
		switch(_g) {
		case "AssignmentExpression":
			var path = this.getIdentifier(expression.left);
			if(path.length > 0) {
				var name = path[0];
				switch(name) {
				case "$hxClasses":
					var moduleName = this.getIdentifier(expression.right);
					if(moduleName.length == 1) {
						this.tag(moduleName[0],def);
					}
					break;
				case "$hx_exports":
					break;
				default:
					if(Object.prototype.hasOwnProperty.call(this.types,name)) {
						if(path[1] == "displayName") {
							this.trySetHot(name);
						} else if(path[1] == "__fileName__") {
							this.trySetHot(name);
						}
					}
					this.tag(name,def);
				}
			}
			break;
		case "CallExpression":
			var path1 = this.getIdentifier(expression.callee.object);
			var prop = this.getIdentifier(expression.callee.property);
			if(prop.length == 1 && path1.length == 1) {
				var name1 = path1[0];
				var member = prop[0];
				if(Object.prototype.hasOwnProperty.call(this.types,name1)) {
					if(member == "main") {
						this.mainModule = name1;
					}
					this.tag(name1,def);
				} else if(name1 == "Object" && this.objectMethods[member] && expression["arguments"] != null && expression["arguments"][0] != null) {
					path1 = this.getIdentifier(expression["arguments"][0].object);
					if(path1.length == 1) {
						name1 = path1[0];
						if(Object.prototype.hasOwnProperty.call(this.types,name1)) {
							this.tag(name1,def);
						}
					}
				}
			}
			break;
		default:
		}
	}
	,trySetHot: function(name) {
		if(this.isHot == null) {
			this.isHot = { };
		}
		if(Object.prototype.hasOwnProperty.call(this.isHot,name)) {
			this.isHot[name] = true;
		} else {
			this.isHot[name] = false;
		}
	}
	,inspectDeclarations: function(declarations,def) {
		var _g = 0;
		while(_g < declarations.length) {
			var decl = declarations[_g];
			++_g;
			if(decl.id != null) {
				var name = decl.id.name;
				if(decl.init != null) {
					var init = decl.init;
					var _g1 = init.type;
					switch(_g1) {
					case "AssignmentExpression":
						var right = init.right;
						var type = right.type;
						if(type == "FunctionExpression") {
							this.tag(name,def);
						} else if(type == "ObjectExpression") {
							if(this.isEnumDecl(right)) {
								this.isEnum[name] = true;
							}
							this.tag(name,def);
						} else if(type == "Identifier") {
							this.tag(name,def);
						}
						break;
					case "CallExpression":
						if(this.isRequireDecl(init.callee)) {
							this.required(name,def);
						}
						break;
					case "FunctionExpression":
						this.tag(name,def);
						break;
					case "Identifier":
						if(name.charAt(0) != "$") {
							this.tag(name,def);
						}
						break;
					case "LogicalExpression":
						if(name == "$hxEnums") {
							this.tag(name,def);
						} else if(init.operator == "||" && init.right != null) {
							var id = this.getIdentifier(init.right);
							if(id.length > 0 && id[0].indexOf("_compat_") > 0) {
								this.tag(name,def);
							}
						}
						break;
					case "MemberExpression":
						if(init.object.type == "CallExpression" && this.isRequireDecl(init.object.callee)) {
							this.required(name,def);
						}
						break;
					case "ObjectExpression":
						if(this.isEnumDecl(init)) {
							this.isEnum[name] = true;
						}
						this.tag(name,def);
						break;
					default:
					}
				}
			}
		}
	}
	,required: function(name,def) {
		this.isRequire[name] = true;
		this.tag(name,def);
	}
	,tag: function(name,def) {
		if(!Object.prototype.hasOwnProperty.call(this.types,name)) {
			if(this.reservedTypes[name]) {
				if(name != "__map_reserved") {
					def.__tag__ = "__reserved__";
				}
				return;
			}
			this.types[name] = [def];
		} else {
			this.types[name].push(def);
		}
		if(def.__tag__ == null) {
			def.__tag__ = name;
		}
	}
	,isEnumDecl: function(node) {
		var props = node.properties;
		if(node.type == "ObjectExpression" && props != null && props.length > 0) {
			return this.getIdentifier(props[0].key)[0] == "__ename__";
		} else {
			return false;
		}
	}
	,isRequireDecl: function(node) {
		if(node != null && node.type == "Identifier") {
			return node.name == "require";
		} else {
			return false;
		}
	}
	,getBodyNodes: function(node) {
		if((node.body instanceof Array) && node.body.__enum__ == null) {
			return node.body;
		} else {
			return [node.body];
		}
	}
	,getIdentifier: function(left) {
		if(left == null) {
			return [];
		}
		var _g = left.type;
		switch(_g) {
		case "Identifier":
			return [left.name];
		case "Literal":
			return [left.raw];
		case "MemberExpression":
			return this.getIdentifier(left.object).concat(this.getIdentifier(left.property));
		default:
			return [];
		}
	}
};
var Reflect = function() { };
Reflect.__name__ = true;
Reflect.fields = function(o) {
	var a = [];
	if(o != null) {
		var hasOwnProperty = Object.prototype.hasOwnProperty;
		for( var f in o ) {
		if(f != "__id__" && f != "hx__closures__" && hasOwnProperty.call(o,f)) {
			a.push(f);
		}
		}
	}
	return a;
};
Reflect.deleteField = function(o,field) {
	if(!Object.prototype.hasOwnProperty.call(o,field)) {
		return false;
	}
	delete(o[field]);
	return true;
};
var Reporter = function(enabled) {
	this.enabled = enabled;
	this.stats = { };
};
Reporter.__name__ = true;
Reporter.prototype = {
	save: function(output) {
		if(!this.enabled) {
			return;
		}
		haxe_Log.trace("Size report: " + output + ".stats.json",{ fileName : "Reporter.hx", lineNumber : 30, className : "Reporter", methodName : "save"});
		this.calculate_rec(this.stats);
		var raw = JSON.stringify(this.stats,null,"  ");
		js_node_Fs.writeFileSync(output + ".stats.json",raw);
		var src = js_node_Fs.readFileSync(js_node_Path.join(__dirname,"viewer.js"));
		var viewer = "<!DOCTYPE html><body><script>var __STATS__ = " + raw + ";\n" + Std.string(src) + "</script></body>";
		js_node_Fs.writeFileSync(output + ".stats.html",viewer);
	}
	,calculate_rec: function(group) {
		var total = 0;
		var _g = 0;
		var _g1 = Reflect.fields(group);
		while(_g < _g1.length) {
			var key = _g1[_g];
			++_g;
			total += group[key].size;
		}
		var _g2 = 0;
		var _g11 = Reflect.fields(group);
		while(_g2 < _g11.length) {
			var key1 = _g11[_g2];
			++_g2;
			var node = group[key1];
			node.rel = Math.round(1000 * node.size / total) / 10;
			if(node.group != null) {
				this.calculate_rec(node.group);
			}
		}
	}
	,includedBefore: function(size) {
		if(!this.enabled || size < 50) {
			return;
		}
		this.current.size += size;
		this.current.group["INCLUDE"] = { size : size, rel : 0};
	}
	,start: function(bundle) {
		if(!this.enabled) {
			return;
		}
		this.current = { size : 0, rel : 0, group : { }};
		this.stats[bundle.name + ".js"] = this.current;
	}
	,add: function(tag,size) {
		if(!this.enabled) {
			return;
		}
		this.current.size += size;
		if(tag == null || tag == "__reserved__" || tag.charAt(0) == "$") {
			return;
		}
		var parts = tag.indexOf("_$") < 0 ? tag.split("_") : this.safeSplit(tag);
		if(parts.length == 1) {
			parts.unshift("TOPLEVEL");
		}
		var parent = this.current;
		var _g = 0;
		while(_g < parts.length) {
			var p = parts[_g];
			++_g;
			if(parent.group == null) {
				parent.group = { };
			}
			var node = parent.group[p];
			if(node == null) {
				node = { size : 0, rel : 0};
				parent.group[p] = node;
			}
			node.size += size;
			parent = node;
		}
	}
	,safeSplit: function(tag) {
		var p = [];
		var acc = "";
		var _g1 = 0;
		var _g = tag.length;
		while(_g1 < _g) {
			var i = _g1++;
			var c = tag.charAt(i);
			if(c != "_") {
				if(c != "$" || tag.charAt(i - 1) != "_") {
					acc += c;
				}
			} else if(tag.charAt(i + 1) != "$") {
				p.push(acc);
				acc = "";
			} else {
				acc += "_";
			}
		}
		p.push(acc);
		return p;
	}
};
var SM = require("@elsassph/fast-source-map");
var SourceMap = function(input,src) {
	var p = src.lastIndexOf("//# sourceMappingURL=");
	if(p < 0) {
		return;
	}
	this.fileName = StringTools.trim(HxOverrides.substr(src,p + "//# sourceMappingURL=".length,null));
	this.fileName = js_node_Path.join(js_node_Path.dirname(input),this.fileName);
	this.source = SM.decodeFile(this.fileName);
};
SourceMap.__name__ = true;
SourceMap.prototype = {
	emitMappings: function(nodes,offset) {
		if(nodes.length == 0 || this.source == null) {
			return null;
		}
		var inc = [];
		var line = offset;
		var _g = 0;
		while(_g < nodes.length) {
			var node = nodes[_g];
			++_g;
			var _g2 = node.loc.start.line;
			var _g1 = node.loc.end.line + 1;
			while(_g2 < _g1) {
				var i = _g2++;
				inc[i] = line++;
			}
		}
		var output = [];
		var map = { version : 3, file : "", sourceRoot : "", sources : [], sourcesContent : [], names : [], mappings : null};
		var usedSources = [];
		try {
			var mappings = this.source.mappings;
			var srcLength = mappings.length;
			var maxLine = 0;
			var _g11 = 0;
			var _g3 = srcLength;
			while(_g11 < _g3) {
				var i1 = _g11++;
				var mapping = mappings[i1];
				if(!isNaN(inc[i1])) {
					var _g21 = 0;
					while(_g21 < mapping.length) {
						var m = mapping[_g21];
						++_g21;
						usedSources[m.src] = true;
					}
					var mapLine = inc[i1];
					output[mapLine] = mapping;
					if(mapLine > maxLine) {
						maxLine = mapLine;
					} else {
						maxLine = maxLine;
					}
				}
			}
			var _g12 = 0;
			var _g4 = maxLine;
			while(_g12 < _g4) {
				var i2 = _g12++;
				if(output[i2] == null) {
					output[i2] = [];
				}
			}
			var _g13 = 0;
			var _g5 = this.source.sources.length;
			while(_g13 < _g5) {
				var i3 = _g13++;
				map.sources[i3] = usedSources[i3] ? this.source.sources[i3] : "";
			}
			map.sourceRoot = this.source.sourceRoot;
			map.mappings = output;
			return SM.encode(map);
		} catch( err ) {
			haxe_Log.trace("Invalid source-map",{ fileName : "SourceMap.hx", lineNumber : 119, className : "SourceMap", methodName : "emitMappings"});
			return null;
		}
	}
	,emitFile: function(output,map) {
		if(map == null) {
			return null;
		}
		map.file = js_node_Path.basename(output);
		return map;
	}
};
var Std = function() { };
Std.__name__ = true;
Std.string = function(s) {
	return js_Boot.__string_rec(s,"");
};
var StringTools = function() { };
StringTools.__name__ = true;
StringTools.isSpace = function(s,pos) {
	var c = HxOverrides.cca(s,pos);
	if(!(c > 8 && c < 14)) {
		return c == 32;
	} else {
		return true;
	}
};
StringTools.ltrim = function(s) {
	var l = s.length;
	var r = 0;
	while(r < l && StringTools.isSpace(s,r)) ++r;
	if(r > 0) {
		return HxOverrides.substr(s,r,l - r);
	} else {
		return s;
	}
};
StringTools.rtrim = function(s) {
	var l = s.length;
	var r = 0;
	while(r < l && StringTools.isSpace(s,l - r - 1)) ++r;
	if(r > 0) {
		return HxOverrides.substr(s,0,l - r);
	} else {
		return s;
	}
};
StringTools.trim = function(s) {
	return StringTools.ltrim(StringTools.rtrim(s));
};
var acorn_Acorn = require("acorn");
var acorn_Walk = require("acorn/dist/walk");
var graphlib_Graph = require("graphlib").Graph;
var haxe_IMap = function() { };
haxe_IMap.__name__ = true;
var haxe_Log = function() { };
haxe_Log.__name__ = true;
haxe_Log.trace = function(v,infos) {
	js_Boot.__trace(v,infos);
};
var haxe_ds_StringMap = function() { };
haxe_ds_StringMap.__name__ = true;
haxe_ds_StringMap.__interfaces__ = [haxe_IMap];
var haxe_io_Bytes = function(data) {
	this.length = data.byteLength;
	this.b = new Uint8Array(data);
	this.b.bufferValue = data;
	data.hxBytes = this;
	data.bytes = this.b;
};
haxe_io_Bytes.__name__ = true;
var js__$Boot_HaxeError = function(val) {
	Error.call(this);
	this.val = val;
	this.message = String(val);
	if(Error.captureStackTrace) {
		Error.captureStackTrace(this,js__$Boot_HaxeError);
	}
};
js__$Boot_HaxeError.__name__ = true;
js__$Boot_HaxeError.wrap = function(val) {
	if((val instanceof Error)) {
		return val;
	} else {
		return new js__$Boot_HaxeError(val);
	}
};
js__$Boot_HaxeError.__super__ = Error;
js__$Boot_HaxeError.prototype = $extend(Error.prototype,{
});
var js_Boot = function() { };
js_Boot.__name__ = true;
js_Boot.__unhtml = function(s) {
	return s.split("&").join("&amp;").split("<").join("&lt;").split(">").join("&gt;");
};
js_Boot.__trace = function(v,i) {
	var msg = i != null ? i.fileName + ":" + i.lineNumber + ": " : "";
	msg += js_Boot.__string_rec(v,"");
	if(i != null && i.customParams != null) {
		var _g = 0;
		var _g1 = i.customParams;
		while(_g < _g1.length) {
			var v1 = _g1[_g];
			++_g;
			msg += "," + js_Boot.__string_rec(v1,"");
		}
	}
	var d;
	var tmp;
	if(typeof(document) != "undefined") {
		d = document.getElementById("haxe:trace");
		tmp = d != null;
	} else {
		tmp = false;
	}
	if(tmp) {
		d.innerHTML += js_Boot.__unhtml(msg) + "<br/>";
	} else if(typeof console != "undefined" && console.log != null) {
		console.log(msg);
	}
};
js_Boot.__string_rec = function(o,s) {
	if(o == null) {
		return "null";
	}
	if(s.length >= 5) {
		return "<...>";
	}
	var t = typeof(o);
	if(t == "function" && (o.__name__ || o.__ename__)) {
		t = "object";
	}
	switch(t) {
	case "function":
		return "<function>";
	case "object":
		if(o instanceof Array) {
			if(o.__enum__) {
				if(o.length == 2) {
					return o[0];
				}
				var str = o[0] + "(";
				s += "\t";
				var _g1 = 2;
				var _g = o.length;
				while(_g1 < _g) {
					var i = _g1++;
					if(i != 2) {
						str += "," + js_Boot.__string_rec(o[i],s);
					} else {
						str += js_Boot.__string_rec(o[i],s);
					}
				}
				return str + ")";
			}
			var l = o.length;
			var i1;
			var str1 = "[";
			s += "\t";
			var _g11 = 0;
			var _g2 = l;
			while(_g11 < _g2) {
				var i2 = _g11++;
				str1 += (i2 > 0 ? "," : "") + js_Boot.__string_rec(o[i2],s);
			}
			str1 += "]";
			return str1;
		}
		var tostr;
		try {
			tostr = o.toString;
		} catch( e ) {
			return "???";
		}
		if(tostr != null && tostr != Object.toString && typeof(tostr) == "function") {
			var s2 = o.toString();
			if(s2 != "[object Object]") {
				return s2;
			}
		}
		var k = null;
		var str2 = "{\n";
		s += "\t";
		var hasp = o.hasOwnProperty != null;
		for( var k in o ) {
		if(hasp && !o.hasOwnProperty(k)) {
			continue;
		}
		if(k == "prototype" || k == "__class__" || k == "__super__" || k == "__interfaces__" || k == "__properties__") {
			continue;
		}
		if(str2.length != 2) {
			str2 += ", \n";
		}
		str2 += s + k + " : " + js_Boot.__string_rec(o[k],s);
		}
		s = s.substring(1);
		str2 += "\n" + s + "}";
		return str2;
	case "string":
		return o;
	default:
		return String(o);
	}
};
var js_node_Fs = require("fs");
var js_node_Path = require("path");
var js_node_buffer_Buffer = require("buffer").Buffer;
String.__name__ = true;
Array.__name__ = true;
Date.__name__ = ["Date"];
var __map_reserved = {};
Bundler.REQUIRE = "var require = (function(r){ return function require(m) { return r[m]; } })($s.__registry__ || {});\n";
Bundler.SCOPE = "typeof exports != \"undefined\" ? exports : typeof window != \"undefined\" ? window : typeof self != \"undefined\" ? self : this";
Bundler.GLOBAL = "typeof window != \"undefined\" ? window : typeof global != \"undefined\" ? global : typeof self != \"undefined\" ? self : this";
Bundler.FUNCTION_START = "(function ($hx_exports, $global) { \"use-strict\";\n";
Bundler.FUNCTION_END = "})(" + "typeof exports != \"undefined\" ? exports : typeof window != \"undefined\" ? window : typeof self != \"undefined\" ? self : this" + ", " + "typeof window != \"undefined\" ? window : typeof global != \"undefined\" ? global : typeof self != \"undefined\" ? self : this" + ");\n";
Bundler.WP_START = "/* eslint-disable */ \"use strict\"\n";
Bundler.FRAGMENTS = { MAIN : { EXPORTS : "var $hx_exports = module.exports, $global = global;\n", SHARED : "var $s = $global.$hx_scope = $global.$hx_scope || {};\n"}, CHILD : { EXPORTS : "var $hx_exports = module.exports, $global = global;\n", SHARED : "var $s = $global.$hx_scope, $_;\n"}};
Bundler.generateHtml = global.generateHtml;
MinifyId.BASE_16 = "abcdefghijklmnop".split("");
SourceMap.SRC_REF = "//# sourceMappingURL=";
})(typeof exports != "undefined" ? exports : typeof window != "undefined" ? window : typeof self != "undefined" ? self : this);
